pub struct VigenereCipher { /* private fields */ }Expand description
A Vigenere cipher implementation.
This cipher uses a keyword to perform a series of Caesar ciphers on the plaintext. It is a classic example of a polyalphabetic substitution cipher.
Implementations